@@ -195,16 +195,19 @@ class SitesInfo:
                   self.sites[site]['state'] = 'restrictedByPegasus'
 
       for site in self.sites:
-         members = self.sites[site]['members']
-         if len(members) > 0:
-            markedForDeletion = []
-            for member in members:
-               if member in self.sites:
-                  if self.sites[member]['state'] != 'enabled':
-                     markedForDeletion.append(member)
-            for member in markedForDeletion:
-               self.sites[site]['members'].remove(member)
-            del markedForDeletion
+         if self.sites[site]['state'] == 'enabled':
+            members = self.sites[site]['members']
+            if len(members) > 0:
+               markedForDeletion = []
+               for member in members:
+                  if member in self.sites:
+                     if self.sites[member]['state'] != 'enabled':
+                        markedForDeletion.append(member)
+               for member in markedForDeletion:
+                  self.sites[site]['members'].remove(member)
+               del markedForDeletion
+               if len(members) == 0:
+                  self.sites[site]['state'] = 'restrictedEmptyMemberList'
 
       for site in self.sites:
          failoverSite = self.sites[site]['failoverSite']
@@ -828,7 +831,7 @@ class SitesInfo:
       siteInfo['remoteManager']                    = ""
       siteInfo['hostAttributes']                   = ""
       siteInfo['executableClassificationsAllowed'] = ['*']
-      siteInfo['remotePpn']                        = ""
+      siteInfo['remotePpn']                        = "1"
       siteInfo['pegasusTemplates']                 = []
 
       return(siteInfo)
