@@ -519,13 +519,18 @@ class VenueMechanismCore:
 
    def stageFilesToInstanceDirectory(self):
       if self.instanceDirectory != "":
-         if self.instanceDirectory != os.getcwd():
-            if os.path.isdir(self.instanceDirectory):
-               if self.stageInTarFile != "":
-                  srcPath = os.path.join(os.getcwd(),self.stageInTarFile)
-                  if os.path.exists(srcPath):
-                     dstPath = os.path.join(self.instanceDirectory,self.stageInTarFile)
-                     os.rename(srcPath,dstPath)
+         try:
+            currentWorkingDirectory = os.getcwd()
+         except (IOError,OSError):
+            self.logger.log(logging.ERROR,getLogMessage("stageFilesToInstanceDirectory:os.getcwd(): No such file or directory"))
+         else:
+            if self.instanceDirectory != currentWorkingDirectory:
+               if os.path.isdir(self.instanceDirectory):
+                  if self.stageInTarFile != "":
+                     srcPath = os.path.join(currentWorkingDirectory,self.stageInTarFile)
+                     if os.path.exists(srcPath):
+                        dstPath = os.path.join(self.instanceDirectory,self.stageInTarFile)
+                        os.rename(srcPath,dstPath)
 
 
    def registerJob(self):
