@@ -61,6 +61,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                 hubUserName,
                 hubUserId,
                 submitterClass,
+                currentWorkingDirectory,
                 session,
                 distributorPid,
                 batchCommands,
@@ -190,13 +191,13 @@ class VenueMechanismSsh(VenueMechanismCore):
 
       if self.remoteBatchSystem == 'SCRIPT':
          self.isBatchJob           = False
-         self.instanceDirectory    = os.getcwd()
+         self.instanceDirectory    = currentWorkingDirectory
       else:
          self.isBatchJob           = True
          if self.instanceId != "0":
-            self.instanceDirectory = os.path.join(os.getcwd(),self.runName,self.instanceId)
+            self.instanceDirectory = os.path.join(currentWorkingDirectory,self.runName,self.instanceId)
          else:
-            self.instanceDirectory = os.path.join(os.getcwd(),self.runName)
+            self.instanceDirectory = os.path.join(currentWorkingDirectory,self.runName)
          if not os.path.isdir(self.instanceDirectory):
             os.makedirs(self.instanceDirectory)
 
@@ -209,7 +210,7 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.workingDirectory    += "_%s" % (self.instanceId)
          self.scratchDirectory        = self.workingDirectory
       else:
-         self.workingDirectory = os.getcwd()
+         self.workingDirectory = currentWorkingDirectory
          if siteInfo['remoteScratchDirectory']:
             epoch = int(time.mktime(datetime.datetime.utcnow().timetuple()))
             self.scratchDirectory     = os.path.join(siteInfo['remoteScratchDirectory'],"%s_%s" % (str(epoch),localJobId))
